==> linkedlabs-1.0.12-py3-none-any.whl: welcome_page.py <==
from time import sleep
# print("""                                                        """)
# sleep(0.025)
# print(""".     .       .  .   . .   .   . .    +  .""")
# sleep(0.025)
# print("""  .     .  :     .    .. :. .___---------___.""")
# sleep(0.025)
# print("""       .  .   .    .  :.:. _".^ .^ ^.  '.. :"-_. .""")
# sleep(0.025)
# print("""    .  :       .  .  .:../:            . .^  :.:\.""")
# sleep(0.025)
# print("""        .   . :: +. :.:/: .   .    .        . . .:\ """)
# sleep(0.025)
# print(""" .  :    .     . _ :::/:               .  ^ .  . .:\ """)
# sleep(0.025)
# print("""  .. . .   . - : :.:./.                        .  .:\ """)
# sleep(0.025)
# print("""  .      .     . :..|:                    .  .  ^. .:|""")
# sleep(0.025)
# print("""    .       . : : ..||        .                . . !:|""")
# sleep(0.025)
# print("""  .     . . . ::. ::\(                           . :)/""")
# sleep(0.025)
# print(""" .   .     : . : .:.|. ######              .#######::|""")
# sleep(0.025)
# print("""  :.. .  :-  : .:  ::|.#######           ..########:|""")
# sleep(0.025)
# print(""" .  .  .  ..  .  .. :\ ########          :######## :/""")
# sleep(0.025)
# print("""  .        .+ :: : -.:\ ########       . ########.:/""")
# sleep(0.025)
# print("""    .  .+   . . . . :.:\. #######       #######..:/""")
# sleep(0.025)
# print("""      :: . . . . ::.:..:.\           .   .   ..:/""")
# sleep(0.025)
# print("""   .   .   .  .. :  -::::.\.       | |     . .:/""")
# sleep(0.025)
# print("""      .  :  .  .  .-:.":.::.\             ..:/""")
# sleep(0.025)
# print(""" .      -.   . . . .: .:::.:.\.           .:/""")
# sleep(0.025)
# print(""".   .   .  :      : ....::_:..:\   ___.  :/""")
# sleep(0.025)
# print("""   .   .  .   .:. .. .  .: :.:.:\       :/""")
# sleep(0.025)
# print("""     +   .   .   : . ::. :.:. .:.|\  .:/|""")
# sleep(0.025)
# print("""     .         +   .  .  ...:: ..|  --.:|""")
# sleep(0.025)
# print(""".      . . .   .  .  . ... :..:.."(  ..) """)
# sleep(0.025)
# print(""" .   .       .      :  .   .: ::/  .  .::\ """)
# sleep(0.025)
print("""#################################################""")
sleep(0.025)
print("""### LinkedLabs Corp.                          ###""")
sleep(0.050)
print("""### We are all Linked!                        ###""")
sleep(0.050)
# print("""### commercial support at hello@linkedlabs.co  ###""")
sleep(0.025)
print("""#################################################""")
# sleep(0.050)
# print("""------------------------------------------------ """)
# sleep(0.025)
# print("""Thank you for choosing free version of linkedlabs """)
# sleep(0.025)
# print("""------------------------------------------------ """)
# sleep(0.025)


# print("""-------------------------------------------------""")
sleep(0.025)
# print("""This module can be used as follows: """)
# sleep(0.025)
# print("""################################################ """)
# sleep(0.025)
# print("""from linkedlabs import get_similarities """)
# sleep(0.025)
# print("""import pandas as pd""")
# sleep(0.025)
# print("""df = pd.read_pickle("your_pandas_dataframe.pkl") ## Any pandas dataframe""")
# sleep(0.025)
# print("""similarity_df = get_similarities(df)""")
# sleep(0.025)
print("""""")
print("""""")
print("""""")
sleep(0.5)
print("""#################################################""")
print("""For support or commercial usage, please mail us at : """)
print(""" ➡   hello@linkedlabs.co""")
print("""or visit www.linkedlabs.co""")
print("""------------------------------------------------ """)

==> linkedlabs-1.1.10-py3-none-any.whl: welcome_page.py <==
from time import sleep
# print("""                                                        """)
# sleep(0.025)
# print(""".     .       .  .   . .   .   . .    +  .""")
# sleep(0.025)
# print("""  .     .  :     .    .. :. .___---------___.""")
# sleep(0.025)
# print("""       .  .   .    .  :.:. _".^ .^ ^.  '.. :"-_. .""")
# sleep(0.025)
# print("""    .  :       .  .  .:../:            . .^  :.:\.""")
# sleep(0.025)
# print("""        .   . :: +. :.:/: .   .    .        . . .:\ """)
# sleep(0.025)
# print(""" .  :    .     . _ :::/:               .  ^ .  . .:\ """)
# sleep(0.025)
# print("""  .. . .   . - : :.:./.                        .  .:\ """)
# sleep(0.025)
# print("""  .      .     . :..|:                    .  .  ^. .:|""")
# sleep(0.025)
# print("""    .       . : : ..||        .                . . !:|""")
# sleep(0.025)
# print("""  .     . . . ::. ::\(                           . :)/""")
# sleep(0.025)
# print(""" .   .     : . : .:.|. ######              .#######::|""")
# sleep(0.025)
# print("""  :.. .  :-  : .:  ::|.#######           ..########:|""")
# sleep(0.025)
# print(""" .  .  .  ..  .  .. :\ ########          :######## :/""")
# sleep(0.025)
# print("""  .        .+ :: : -.:\ ########       . ########.:/""")
# sleep(0.025)
# print("""    .  .+   . . . . :.:\. #######       #######..:/""")
# sleep(0.025)
# print("""      :: . . . . ::.:..:.\           .   .   ..:/""")
# sleep(0.025)
# print("""   .   .   .  .. :  -::::.\.       | |     . .:/""")
# sleep(0.025)
# print("""      .  :  .  .  .-:.":.::.\             ..:/""")
# sleep(0.025)
# print(""" .      -.   . . . .: .:::.:.\.           .:/""")
# sleep(0.025)
# print(""".   .   .  :      : ....::_:..:\   ___.  :/""")
# sleep(0.025)
# print("""   .   .  .   .:. .. .  .: :.:.:\       :/""")
# sleep(0.025)
# print("""     +   .   .   : . ::. :.:. .:.|\  .:/|""")
# sleep(0.025)
# print("""     .         +   .  .  ...:: ..|  --.:|""")
# sleep(0.025)
# print(""".      . . .   .  .  . ... :..:.."(  ..) """)
# sleep(0.025)
# print(""" .   .       .      :  .   .: ::/  .  .::\ """)
# sleep(0.025)
print("""###############################################################""")
sleep(0.025)
print("""### LinkedLabs Corp.                                        ###""")
sleep(0.050)
print("""### We are all Linked!                                      ###""")
sleep(0.050)
# print("""### commercial support at hello@linkedlabs.co  ###""")
sleep(0.025)
print("""###############################################################""")
# sleep(0.050)
# print("""------------------------------------------------ """)
# sleep(0.025)
# print("""Thank you for choosing free version of linkedlabs """)
# sleep(0.025)
# print("""------------------------------------------------ """)
# sleep(0.025)


# print("""-------------------------------------------------""")
sleep(0.025)
# print("""This module can be used as follows: """)
# sleep(0.025)
# print("""################################################ """)
# sleep(0.025)
# print("""from linkedlabs import get_similarities """)
# sleep(0.025)
# print("""import pandas as pd""")
# sleep(0.025)
# print("""df = pd.read_pickle("your_pandas_dataframe.pkl") ## Any pandas dataframe""")
# sleep(0.025)
# print("""similarity_df = get_similarities(df)""")
# sleep(0.025)
print("""""")
print("""""")
print("""""")
sleep(0.5)
print("""###############################################################""")
print("""### For support or commercial usage, please mail us at :    ###""")
print("""### ➡   hello@linkedlabs.co                                 ###""")
print("""### or visit www.linkedlabs.co                              ###""")
print("""###############################################################""")
